This package provides a method to plot one or several dataseries against the chromosomal ideogram. It provides some simple options (vertical/horizontal orientation, display in bars or linegraphs). Data are expected to be binned; IdeoViz provides a function for user-specified bin widths. Ideograms for the genome of choice can also be automatically downloaded from UCSC using the getIdeo() function.
| Package: |
| IdeoViz |
| Type: |
| Package |
| Title: |
| Plots data (continuous/discrete) along chromosomal ideogram |
| Version: |
| 0.99.1 |
| Date: |
| 2013-06-26 |
| Author: |
| Shraddha Pai |
| Maintainer: |
| Shraddha Pai |
| Depends: |
| Biobase, IRanges, GenomicRanges, RColorBrewer, rtracklayer |
| biocViews: |
| Visualization,Microarray |
| License: |
| GPL-2 |